"""
arifos_core/integration/synthesis - Neuro-Symbolic Bridge (666)

Δ+Ω Unification - Bridging AGI logic and ASI care.
"""

from arifos_core.integration.synthesis.neuro_symbolic_bridge import (
    NeuroSymbolicBridge,
    BridgeBundle666,
    MoEWeights,
    ConflictResolution,
    ConflictType,
    GatingCondition,
    synthesize_delta_omega
)

__all__ = [
    "NeuroSymbolicBridge",
    "BridgeBundle666",
    "MoEWeights",
    "ConflictResolution",
    "ConflictType",
    "GatingCondition",
    "synthesize_delta_omega"
]
